/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef STATIONINFOWINDOW_H
#define STATIONINFOWINDOW_H

#include "stackedwindow.h"

class QUrl;
class Station;
class QLabel;
class ScrollArea;

class StationInfoWindow : public StackedWindow
{
    Q_OBJECT

public:
    explicit StationInfoWindow(Station *station, QWidget *parent = 0);

private:
    void setLandscapeLayout();
    void setPortraitLayout();

private slots:
    void playStation();
    void toggleFavourite();
    void showEditDialog();
    void deleteStation();

    void onTitleChanged(const QString &title);
    void onDescriptionChanged(const QString &description);
    void onGenreChanged(const QString &genre);
    void onCountryChanged(const QString &country);
    void onLanguageChanged(const QString &language);
    void onSourceChanged(const QUrl &source);
    void onLastPlayedChanged(qint64 lastPlayed);
    void onFavouriteChanged(bool favourite);
    void onCurrentStationChanged(Station *station);
    
private:
    Station *m_station;

    QAction *m_playAction;
    QAction *m_favouriteAction;
    QAction *m_editAction;
    QAction *m_deleteAction;

    QLabel *m_descriptionLabel;
    QLabel *m_genreLabel;
    QLabel *m_countryLabel;
    QLabel *m_languageLabel;
    QLabel *m_sourceLabel;
    QLabel *m_lastPlayedLabel;

    ScrollArea *m_scrollArea;
};

#endif // STATIONINFOWINDOW_H
